import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

Widget text20W400(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 20.sp,
        color: Colors.white,
        fontWeight: FontWeight.w400,
        fontFamily: 'manrope'),
  );
}

Widget text18W800(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 18.sp,
        color: Colors.white,
        fontWeight: FontWeight.w800,
        fontFamily: 'manrope'),
  );
}

Widget text18W600(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 18.sp,
        color: Colors.white,
        fontWeight: FontWeight.w600,
        fontFamily: 'manrope'),
  );
}

Widget text18W500(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 18.sp,
        color: Colors.white,
        fontWeight: FontWeight.w500,
        fontFamily: 'manrope'),
  );
}

Widget text18W400(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 18.sp,
        color: Colors.white,
        fontWeight: FontWeight.w400,
        fontFamily: 'manrope'),
  );
}

Widget text16W400(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 16.sp,
        color: Colors.white,
        fontWeight: FontWeight.w400,
        fontFamily: 'manrope'),
  );
}

Widget text16W400_1B1B1B(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 16.sp,
        color: Color(0Xff1B1B1B),
        fontWeight: FontWeight.w400,
        fontFamily: 'manrope'),
  );
}

Widget text12W500_B4B4B4(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 12.sp,
        color: Color(0XffB4B4B4),
        fontWeight: FontWeight.w500,
        fontFamily: 'manrope'),
  );
}

Widget text14W600_1B1B1B(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 14.sp,
        color: Color(0Xff1B1B1B),
        fontWeight: FontWeight.w600,
        fontFamily: 'manrope'),
  );
}

Widget text16W600(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 16.sp,
        color: Colors.white,
        fontWeight: FontWeight.w600,
        fontFamily: 'manrope'),
  );
}

Widget text16W500(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 16.sp,
        color: Colors.white,
        fontWeight: FontWeight.w500,
        fontFamily: 'manrope'),
  );
}

Widget text15W600(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 15.sp,
        color: Colors.white,
        fontWeight: FontWeight.w600,
        fontFamily: 'manrope'),
  );
}

Widget text15W600_00FF19(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 15.sp,
        color: Color(0xFF00FF19),
        fontWeight: FontWeight.w600,
        fontFamily: 'manrope'),
  );
}

Widget text12W400(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 12.sp,
        color: Colors.white,
        fontWeight: FontWeight.w400,
        fontFamily: 'manrope'),
  );
}
Widget text12W500(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 12.sp,
        color: Colors.white,
        fontWeight: FontWeight.w500,
        fontFamily: 'manrope'),
  );
}

Widget text8W400(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 8.sp,
        color: Colors.white,
        fontWeight: FontWeight.w400,
        fontFamily: 'manrope'),
  );
}

Widget text22W600(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 22.sp,
        color: Colors.white,
        fontWeight: FontWeight.w600,
        fontFamily: 'manrope'),
  );
}

Widget text25W600(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 25.sp,
        color: Colors.white,
        fontWeight: FontWeight.w600,
        fontFamily: 'manrope'),
  );
}

Widget text22W500(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 22.sp,
        color: Colors.white,
        fontWeight: FontWeight.w500,
        fontFamily: 'manrope'),
  );
}

Widget text16W700(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 16.sp,
        color: Colors.white,
        fontWeight: FontWeight.w700,
        fontFamily: 'manrope'),
  );
}

Widget text14W300(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 14.sp,
        color: Colors.white,
        fontWeight: FontWeight.w300,
        fontFamily: 'manrope'),
  );
}

Widget text14W400(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 14.sp,
        color: Colors.white,
        fontWeight: FontWeight.w400,
        fontFamily: 'manrope'),
  );
}

Widget text14W500(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 14.sp,
        color: Colors.white,
        fontWeight: FontWeight.w500,
        fontFamily: 'manrope'),
  );
}

Widget text16W400_DADADA(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 16.sp,
        color: Color(0xFFDADADA),
        fontWeight: FontWeight.w400,
        fontFamily: 'manrope'),
  );
}

Widget text14W400_979797(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 14.sp,
        color: Color(0xFF979797),
        fontWeight: FontWeight.w400,
        fontFamily: 'manrope'),
  );
}

Widget text12W400_979797(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 12.sp,
        color: Color(0xFF979797),
        fontWeight: FontWeight.w400,
        fontFamily: 'manrope'),
  );
}

Widget text14W400_00FF19(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 14.sp,
        color: Color(0xFF00FF19),
        fontWeight: FontWeight.w400,
        fontFamily: 'manrope'),
  );
}

Widget text14W500_black(String text) {
  return Text(
    text,
    style: TextStyle(
        fontSize: 14.sp,
        color: Colors.black,
        fontWeight: FontWeight.w500,
        fontFamily: 'manrope'),
  );
}
